package de.ozgcloud.eingang.fim;

import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.Optional;

import org.apache.commons.collections4.MapUtils;

import lombok.AccessLevel;
import lombok.NoArgsConstructor;

@NoArgsConstructor(access = AccessLevel.PRIVATE)
class FimDataUtil {

	static final String VALUE_KEY = "value";

	public static Optional<String> getValue(Map<String, Object> data, List<String> pathKeys, String key) {
		var current = FimDataUtil.getSubmap(data, pathKeys);
		if (Objects.isNull(current)) {
			return Optional.empty();
		}
		return FimDataUtil.getValueByKey(current, key);
	}

	private static Map<String, Object> getSubmap(Map<String, Object> data, List<String> pathKeys) {
		var current = data;
		for (var pathKey : pathKeys) {
			current = FimDataUtil.getValueMapByKey(current, pathKey);
		}
		return current;
	}

	static Map<String, Object> getValueMapByKey(Map<String, Object> obj, String key) {
		return Optional.ofNullable(MapUtils.getMap(obj, key))
				.map(FimDataUtil::castToMap)
				.map(FimDataUtil::getValueAsMap)
				.orElse(null);
	}

	public static Optional<String> getValueByKey(Map<String, Object> data, String key) {
		var map = FimDataUtil.castToMap(MapUtils.getMap(data, key));
		return Optional.ofNullable(MapUtils.getString(map, VALUE_KEY));
	}

	@SuppressWarnings("unchecked")
	private static Map<String, Object> castToMap(Map<?, ?> obj) {
		return (Map<String, Object>) obj;
	}

	private static Map<String, Object> getValueAsMap(Map<String, Object> map) {
		return FimDataUtil.castToMap(MapUtils.getMap(map, VALUE_KEY));
	}
}