package de.ozgcloud.eingang.fim;

import java.util.List;

import jakarta.annotation.PostConstruct;

import org.springframework.core.io.ResourceLoader;
import org.springframework.stereotype.Component;

import lombok.RequiredArgsConstructor;

@RequiredArgsConstructor
@Component
class FimSchemeHelper {

	private final FimProperties fimProperties;
	private final ResourceLoader resourceLoader;
	private final List<FimSchemeAdapter> fimSchemeAdapters;

	private FimSchemeAdapterCatalogue schemeAdapterCatalogue;
	private FimSchemeCatalogue schemeCatalogue;

	@PostConstruct
	void init() {
		initSchemeAdapterCatalogue();
		initSchemeCatalogue();
	}

	private void initSchemeAdapterCatalogue() {
		schemeAdapterCatalogue = new FimSchemeAdapterCatalogue();

		fimSchemeAdapters.forEach(adapter -> schemeAdapterCatalogue.put(adapter.getIdentifier(), adapter));
	}

	private void initSchemeCatalogue() {
		schemeCatalogue = new FimSchemeCatalogue(fimProperties, resourceLoader, schemeAdapterCatalogue);
	}

	public FimScheme getScheme(String identifier) {
		return schemeCatalogue.get(FimSchemeIdentifier.fromString(identifier));
	}

	public FimScheme getDefaultScheme() {
		return schemeCatalogue.get(UnknownSchemeAdapter.IDENTIFIER);
	}
}